write_entry_source

Function write_entry_source 

pub fn write_entry_source(
    path: &Path,
    source: &str,
) -> Result<(), ToolchainError>
Writes source to the entry module’s source file, creating any parent module directories first.

Errors

Returns ToolchainError::Io when a parent directory cannot be created or the file cannot be written.